body {
	background:black;	padding:0;
	margin:0;
	}
video {
	width:100%; height:100%;	padding:0;
	margin:0;
	}
iframe {
	position:absolute;
	left:0; 
	top:0;
	width:100%; height:100%;
	padding:0;
	margin:0;
	}
div {
	display: flex;
	justify-content: center; /* align horizontal */
	align-items: center; /* align vertical */
	vertical-align:middle;
	border:0px solid white;
	height:100vh;
	padding:0;
	margin:0;
	}